@@ -1,6 +1,6 @@
 import abc
 
-from six import string_types
+from six import string_types, with_metaclass
 
 
 class FieldFactory(object):
@@ -35,7 +35,7 @@ class FieldFactory(object):
         return None
 
 
-class Field(object):
+class Field(with_metaclass(abc.ABCMeta, object)):
     """
     Abstract field class that all field types extend.
 
@@ -60,7 +60,6 @@ class Field(object):
             This is a flag that is read when adding fields which could indicate some
             other fields need to be automatically created.
     """
-    __metaclass__ = abc.ABCMeta
 
     def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None):
         """
@@ -80,7 +79,6 @@ class Field(object):
         :param distinct: Indicates if a DISTINCT flag should be added during sql generation
         :type cast: bool
         """
-        # TODO: implement distinct
         self.field = field
         self.name = None
         self.table = table
@@ -102,8 +100,8 @@ class Field(object):
         alias = self.get_alias()
         if alias:
             if self.cast:
-                return 'CAST({0} AS {1}) AS {2}'.format(self.get_select_sql(), self.cast.upper(), alias)
-            return '{0} AS {1}'.format(self.get_select_sql(), alias)
+                return 'CAST({0} AS {1}) AS "{2}"'.format(self.get_select_sql(), self.cast.upper(), alias)
+            return '{0} AS "{1}"'.format(self.get_select_sql(), alias)
 
         if self.cast:
             return 'CAST({0} AS {1})'.format(self.get_identifier(), self.cast.upper())
@@ -215,6 +213,25 @@ class SimpleField(Field):
         self.name = field
 
 
+class JsonField(SimpleField):
+    """
+    Used to access postgres native json fields
+    """
+    def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None, key=None):
+        super(JsonField, self).__init__(field, table, alias, cast, distinct)
+        self.key = key
+
+    def get_select_sql(self):
+        if self.table:
+            return '{0}.{1}->\'{2}\''.format(self.table.get_identifier(), self.name, self.key)
+        return '{0}->\'{1}\''.format(self.name, self.key)
+
+    def get_where_key(self):
+        if self.table:
+            return '{0}.{1}->>\'{2}\''.format(self.table.get_identifier(), self.name, self.key)
+        return '{0}->>\'{1}\''.format(self.name, self.key)
+
+
 class MultiField(Field):
     """
     A field that contains one or more nested fields
@@ -235,6 +252,15 @@ class MultiField(Field):
         if self.field and self.field.table is None:
             self.field.set_table(self.table)
 
+    def get_field_identifier(self):
+        """
+        Gets the identifier of the nested field
+
+        :return: the identifier of the nested field
+        :rtype: str
+        """
+        return self.field.get_identifier()
+
 
 class ExpressionField(Field):
     pass
@@ -299,8 +325,9 @@ class AggregateField(MultiField):
         :return: Gets the SELECT field portion for the field without the alias
         :rtype: str
         """
-        return '{0}({1}){2}'.format(
+        return '{0}({1}{2}){3}'.format(
             self.name.upper(),
+            self.get_distinct(),
             self.get_field_identifier(),
             self.get_over(),
         )
@@ -325,6 +352,11 @@ class AggregateField(MultiField):
             return ' {0}'.format(self.over.get_sql())
         return ''
 
+    def get_distinct(self):
+        if self.distinct:
+            return 'DISTINCT '
+        return ''
+
 
 class CountField(AggregateField):
     """
