@@ -1,14 +1,14 @@
 from django.db import connection
-from django.test import TestCase
 from django.test.utils import override_settings
 
 from querybuilder.logger import Logger, LogManager
 from querybuilder.query import Query
+from querybuilder.tests.base import QuerybuilderTestCase
 from querybuilder.tests.models import Account
 
 
 @override_settings(DEBUG=True)
-class LogManagerTest(TestCase):
+class LogManagerTest(QuerybuilderTestCase):
     """
     Includes functions to test the LogManager
     """
@@ -35,7 +35,7 @@ class LogManagerTest(TestCase):
 
 
 @override_settings(DEBUG=True)
-class LoggerTest(TestCase):
+class LoggerTest(QuerybuilderTestCase):
     """
     Includes functions to test the Logger
     """
