@@ -173,7 +173,7 @@ class WhereTest(QueryTestCase):
         ))
 
         query_str = query.get_sql()
-        expected_query = 'SELECT tests_account.* FROM tests_account WHERE (id IN (%(A0)s))'
+        expected_query = 'SELECT querybuilder_tests_account.* FROM querybuilder_tests_account WHERE (id IN (%(A0)s))'
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_where_in_csv(self):
@@ -184,7 +184,9 @@ class WhereTest(QueryTestCase):
         ))
 
         query_str = query.get_sql()
-        expected_query = 'SELECT tests_account.* FROM tests_account WHERE (id IN (%(A0)s,%(A1)s,%(A2)s))'
+        expected_query = (
+            'SELECT querybuilder_tests_account.* FROM querybuilder_tests_account WHERE (id IN (%(A0)s,%(A1)s,%(A2)s))'
+        )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_where_in_list(self):
@@ -195,7 +197,9 @@ class WhereTest(QueryTestCase):
         ))
 
         query_str = query.get_sql()
-        expected_query = 'SELECT tests_account.* FROM tests_account WHERE (id IN (%(A0)s,%(A1)s,%(A2)s))'
+        expected_query = (
+            'SELECT querybuilder_tests_account.* FROM querybuilder_tests_account WHERE (id IN (%(A0)s,%(A1)s,%(A2)s))'
+        )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_where_contains(self):
@@ -210,6 +214,18 @@ class WhereTest(QueryTestCase):
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
         self.assertEqual(query._where.args['A0'], '%some value%', 'Value is not correct')
 
+    def test_where_icontains(self):
+        query = Query().from_table(
+            table='test_table'
+        ).where(Q(
+            field_name__icontains='some value'
+        ))
+
+        query_str = query.get_sql()
+        expected_query = 'SELECT test_table.* FROM test_table WHERE (field_name ILIKE %(A0)s)'
+        self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
+        self.assertEqual(query._where.args['A0'], '%some value%', 'Value is not correct')
+
     def test_where_not_contains(self):
         query = Query().from_table(
             table='test_table'
@@ -222,6 +238,18 @@ class WhereTest(QueryTestCase):
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
         self.assertEqual(query._where.args['A0'], '%some value%', 'Value is not correct')
 
+    def test_where_not_icontains(self):
+        query = Query().from_table(
+            table='test_table'
+        ).where(~Q(
+            field_name__icontains='some value'
+        ))
+
+        query_str = query.get_sql()
+        expected_query = 'SELECT test_table.* FROM test_table WHERE ((NOT(field_name ILIKE %(A0)s)))'
+        self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
+        self.assertEqual(query._where.args['A0'], '%some value%', 'Value is not correct')
+
     def test_where_startswith(self):
         query = Query().from_table(
             table='test_table'
@@ -310,7 +338,11 @@ class WhereTest(QueryTestCase):
         ))
 
         query_str = query.get_sql()
-        expected_query = 'SELECT test_table.* FROM test_table WHERE (one = %(A0)s AND (three = %(A1)s OR five = %(A2)s))'
+        expected_query = (
+            'SELECT test_table.* '
+            'FROM test_table '
+            'WHERE (one = %(A0)s AND (three = %(A1)s OR five = %(A2)s))'
+        )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_where_and_with_not_combined_or(self):
@@ -325,7 +357,11 @@ class WhereTest(QueryTestCase):
         ))
 
         query_str = query.get_sql()
-        expected_query = 'SELECT test_table.* FROM test_table WHERE (one = %(A0)s AND ((NOT(three = %(A1)s)) OR five = %(A2)s))'
+        expected_query = (
+            'SELECT test_table.* '
+            'FROM test_table '
+            'WHERE (one = %(A0)s AND ((NOT(three = %(A1)s)) OR five = %(A2)s))'
+        )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_where_complex(self):
