@@ -60,7 +60,7 @@ class WindowFunctionTest(QueryTestCase):
             ]
         )
         query_str = query.get_sql()
-        expected_query = 'SELECT RANK() AS rank FROM tests_order'
+        expected_query = 'SELECT RANK() AS "rank" FROM querybuilder_tests_order'
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_rank_over(self):
@@ -73,7 +73,7 @@ class WindowFunctionTest(QueryTestCase):
             ]
         )
         query_str = query.get_sql()
-        expected_query = 'SELECT RANK() OVER () AS rank FROM tests_order'
+        expected_query = 'SELECT RANK() OVER () AS "rank" FROM querybuilder_tests_order'
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_rank_over_order(self):
@@ -89,7 +89,9 @@ class WindowFunctionTest(QueryTestCase):
             ]
         )
         query_str = query.get_sql()
-        expected_query = 'SELECT tests_order.id, RANK() OVER (ORDER BY id ASC) AS rank FROM tests_order'
+        expected_query = (
+            'SELECT querybuilder_tests_order.id, RANK() OVER (ORDER BY id ASC) AS "rank" FROM querybuilder_tests_order'
+        )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_rank_over_partition(self):
@@ -105,7 +107,10 @@ class WindowFunctionTest(QueryTestCase):
             ]
         )
         query_str = query.get_sql()
-        expected_query = 'SELECT tests_order.id, RANK() OVER (PARTITION BY account_id) AS rank FROM tests_order'
+        expected_query = (
+            'SELECT querybuilder_tests_order.id, RANK() OVER (PARTITION BY account_id) AS "rank" FROM '
+            'querybuilder_tests_order'
+        )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
     def test_row_number(self):
@@ -124,9 +129,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'ROW_NUMBER() OVER (ORDER BY margin DESC) AS row_number '
-            'FROM tests_order '
+            'SELECT querybuilder_tests_order.*, '
+            'ROW_NUMBER() OVER (ORDER BY margin DESC) AS "row_number" '
+            'FROM querybuilder_tests_order '
             'ORDER BY row_number '
             'ASC'
         )
@@ -150,9 +155,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.id, '
-            'RANK() OVER (PARTITION BY account_id ORDER BY id ASC) AS rank '
-            'FROM tests_order '
+            'SELECT querybuilder_tests_order.id, '
+            'RANK() OVER (PARTITION BY account_id ORDER BY id ASC) AS "rank" '
+            'FROM querybuilder_tests_order '
             'ORDER BY rank '
             'DESC'
         )
@@ -174,9 +179,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'DENSE_RANK() OVER (ORDER BY margin DESC) AS dense_rank '
-            'FROM tests_order '
+            'SELECT querybuilder_tests_order.*, '
+            'DENSE_RANK() OVER (ORDER BY margin DESC) AS "dense_rank" '
+            'FROM querybuilder_tests_order '
             'ORDER BY dense_rank '
             'ASC'
         )
@@ -198,9 +203,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'PERCENT_RANK() OVER (ORDER BY margin DESC) AS percent_rank '
-            'FROM tests_order '
+            'SELECT querybuilder_tests_order.*, '
+            'PERCENT_RANK() OVER (ORDER BY margin DESC) AS "percent_rank" '
+            'FROM querybuilder_tests_order '
             'ORDER BY percent_rank '
             'ASC'
         )
@@ -222,9 +227,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'CUME_DIST() OVER (ORDER BY margin DESC) AS cume_dist '
-            'FROM tests_order '
+            'SELECT querybuilder_tests_order.*, '
+            'CUME_DIST() OVER (ORDER BY margin DESC) AS "cume_dist" '
+            'FROM querybuilder_tests_order '
             'ORDER BY cume_dist '
             'ASC'
         )
@@ -247,9 +252,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'NTILE(2) OVER (ORDER BY margin DESC) AS ntile '
-            'FROM tests_order '
+            'SELECT querybuilder_tests_order.*, '
+            'NTILE(2) OVER (ORDER BY margin DESC) AS "ntile" '
+            'FROM querybuilder_tests_order '
             'ORDER BY ntile '
             'ASC'
         )
@@ -270,9 +275,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'LAG(tests_order.margin, 1) OVER (ORDER BY margin DESC) AS margin_lag '
-            'FROM tests_order'
+            'SELECT querybuilder_tests_order.*, '
+            'LAG(querybuilder_tests_order.margin, 1) OVER (ORDER BY margin DESC) AS "margin_lag" '
+            'FROM querybuilder_tests_order'
         )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
@@ -292,9 +297,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'LAG(tests_order.margin, 1, \'0\') OVER (ORDER BY margin DESC) AS margin_lag '
-            'FROM tests_order'
+            'SELECT querybuilder_tests_order.*, '
+            'LAG(querybuilder_tests_order.margin, 1, \'0\') OVER (ORDER BY margin DESC) AS "margin_lag" '
+            'FROM querybuilder_tests_order'
         )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
@@ -313,9 +318,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'LEAD(tests_order.margin, 1) OVER (ORDER BY margin DESC) AS margin_lead '
-            'FROM tests_order'
+            'SELECT querybuilder_tests_order.*, '
+            'LEAD(querybuilder_tests_order.margin, 1) OVER (ORDER BY margin DESC) AS "margin_lead" '
+            'FROM querybuilder_tests_order'
         )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
@@ -334,9 +339,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'FIRST_VALUE(tests_order.margin) OVER (ORDER BY margin DESC) AS margin_first_value '
-            'FROM tests_order'
+            'SELECT querybuilder_tests_order.*, '
+            'FIRST_VALUE(querybuilder_tests_order.margin) OVER (ORDER BY margin DESC) AS "margin_first_value" '
+            'FROM querybuilder_tests_order'
         )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
@@ -355,9 +360,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'LAST_VALUE(tests_order.margin) OVER (ORDER BY margin ASC) AS margin_last_value '
-            'FROM tests_order'
+            'SELECT querybuilder_tests_order.*, '
+            'LAST_VALUE(querybuilder_tests_order.margin) OVER (ORDER BY margin ASC) AS "margin_last_value" '
+            'FROM querybuilder_tests_order'
         )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
@@ -377,9 +382,9 @@ class WindowFunctionTest(QueryTestCase):
         )
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            'NTH_VALUE(tests_order.margin, 2) OVER (ORDER BY margin DESC) AS margin_nth_value '
-            'FROM tests_order'
+            'SELECT querybuilder_tests_order.*, '
+            'NTH_VALUE(querybuilder_tests_order.margin, 2) OVER (ORDER BY margin DESC) AS "margin_nth_value" '
+            'FROM querybuilder_tests_order'
         )
         self.assertEqual(query_str, expected_query, get_comparison_str(query_str, expected_query))
 
@@ -399,14 +404,14 @@ class WindowFunctionTest(QueryTestCase):
 
         query_str = query.get_sql()
         expected_query = (
-            'SELECT tests_order.*, '
-            '(CASE WHEN (STDDEV(tests_order.margin) OVER ()) <> 0 '
-            'THEN ((tests_order.margin - ('
-            'AVG(tests_order.margin) OVER ())) / (STDDEV(tests_order.margin) OVER ())) '
+            'SELECT querybuilder_tests_order.*, '
+            '(CASE WHEN (STDDEV(querybuilder_tests_order.margin) OVER ()) <> 0 '
+            'THEN ((querybuilder_tests_order.margin - ('
+            'AVG(querybuilder_tests_order.margin) OVER ())) / (STDDEV(querybuilder_tests_order.margin) OVER ())) '
             'ELSE 0 '
             'END) '
-            'AS margin_num_stddev '
-            'FROM tests_order '
+            'AS "margin_num_stddev" '
+            'FROM querybuilder_tests_order '
             'ORDER BY margin_num_stddev '
             'DESC'
         )
